==> fap-0.9.2.tar.bz2: fap-0.9.2/src/audio/input/metaData.h <==
/*
 *  Copyright (C) 2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef METADATA_H
#define METADATA_H

#include <fx.h>

#include "imageData.h"

class metaData {

public:
enum mpris_t {
	LOCATION,
	TITLE,
	ARTIST,
	ALBUM,
	TRACK,
	TIME,
	MTIME,
	GENRE,
	COMMENT,
	RATING,
	YEAR,
	ARTURL,
	LAST_ID
};

public:
	virtual int moreInfo(const int i) const =0;
	virtual const char* getKey(const unsigned int num) const =0;
	virtual const char* getKey(const mpris_t info) const =0;
	virtual const char* getInfo(unsigned int num) const =0;
	virtual const char* getInfo(const char* info) const =0;
	virtual const char* getInfo(const mpris_t info) const =0;
	virtual imageData* getImage(void) const =0;
};

/*****************************************************************/

class metaDataImpl : public metaData {

private:
	static const char* mprisTags[LAST_ID];

private:
	FXStringDict	_infos;

	imageData	*_img;

public:
	metaDataImpl(void) : _img(0) {}

	/// Append song info
	void addInfo(const char* type, const char* info);
	void addInfo(const char* type, unsigned int info);
	void addInfo(const mpris_t type, const char* info);
	void addInfo(const mpris_t type, unsigned int info);
	void addInfo(imageData* img) { _img=img; }

	/// Remove all info
	void clearInfo() { _infos.clear(); delete _img; _img=0; }

	/// Find song info
	const FXchar* findInfo(const char* type) const { return _infos.find(type); }

	/// Get song info
	int moreInfo(const int i) const;

	const char* getKey(const unsigned int num) const { return _infos.key(num); }
	const char* getKey(const mpris_t info) const { return mprisTags[info]; }
	const char* getInfo(const unsigned int num) const { return _infos.data(num); }
	const char* getInfo(const char* info) const { return _infos.find(info); }
	const char* getInfo(const mpris_t info) const { return getInfo(mprisTags[info]); }
	imageData* getImage(void) const { return _img; }
};

#endif

==> fap-0.11.1.tar.bz2: fap-0.11.1/src/audio/input/metaData.h <==
/*
 *  Copyright (C) 2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef METADATA_H
#define METADATA_H

#include <fx.h>

#include "imageData.h"
#include "utils.h"

class metaData {

public:
enum mpris_t {
	LOCATION,
	TITLE,
	ARTIST,
	ALBUM,
	TRACK,
	TIME,
	MTIME,
	GENRE,
	COMMENT,
	RATING,
	YEAR,
	ARTURL,
	LAST_ID
};

public:
	virtual int moreInfo(const int i) const =0;
	virtual const char* getKey(const unsigned int num) const =0;
	virtual const char* getKey(const mpris_t info) const =0;
	virtual const char* getInfo(unsigned int num) const =0;
	virtual const char* getInfo(const char* info) const =0;
	virtual const char* getInfo(const mpris_t info) const =0;
	virtual imageData* getImage(void) const =0;
};

/*****************************************************************/

class metaDataImpl : public metaData {

private:
	static const char* mprisTags[LAST_ID];

private:
	FXStringDict	_infos;

	imageData	*_img;

public:
	metaDataImpl(void) : _img(0) {}

	/// Append song info
	void addInfo(const char* type, const char* info);
	void addInfo(const char* type, unsigned int info);
	void addInfo(const mpris_t type, const char* info);
	void addInfo(const mpris_t type, unsigned int info);
	void addInfo(imageData* img) { _img=img; }

	/// Remove all info
	void clearInfo() { _infos.clear(); delPtr(_img); }

	/// Find song info
	const FXchar* findInfo(const char* type) const { return _infos.find(type); }

	/// Get song info
	int moreInfo(const int i) const;

	const char* getKey(const unsigned int num) const { return _infos.key(num); }
	const char* getKey(const mpris_t info) const { return mprisTags[info]; }
	const char* getInfo(const unsigned int num) const { return _infos.data(num); }
	const char* getInfo(const char* info) const { return _infos.find(info); }
	const char* getInfo(const mpris_t info) const { return getInfo(mprisTags[info]); }
	imageData* getImage(void) const { return _img; }
};

#endif
